Well.ca - Canada's online health, beauty, and skin care store Free Shipping
Description: Shop online at our Canadian health, beauty and skin care store and have everything delivered to your door.
Keywords: Medicine & Health, Personal Care, Vitamins & Supplements, Beauty & Skin Care, Baby & Kids, Diet & Fitness, Green & Natural, House & Home, Gift Cards, Samples, Promotions, Food & Snacks, Gender Based Samples, One Time Samples, Brands, Ostomy, Canada, Canadian

## Stay in the loop!

Be the first to hear about exclusive offers and new arrivals
from these great brands and more!

## Stay in the loop!

Be the first to hear about exclusive offers and new arrivals
from these great brands and more!

### Stocking Stuffers
View All

Next Prev
Add to Cart +
Makers and Merchants Smooth Operator Milk Chocolate
$7.99$6.39
Add to Cart +
Danielle Creations Pop Collection Compact Mirror in Black
$7.99
Add to Cart +
PEPPA Tino Organic Bonding Doll in Lime
$24.99
Add to Cart +
Malechemy by Cocoon Apothecary Bay Rum Aftershave
$21.99
Add to Cart +
Fox Chapel Color Your Own Stickers Letters and Numbers
$9.99
Add to Cart +
Danica Studio Large Linen Cosmetic Bag with Prim & Proper Print
$27.98
Add to Cart +
Maison Apothecare Gentleman's Apothecary Shaving Cream
$33.99$30.59
Add to Cart +
Fox Chapel Color Your Own Stickers Inspiration
$9.99
Add to Cart +
Mr Men and Little Miss Mr Clever Mug
$12.98
Add to Cart +
Now Essential Oils Put Some Pep in Your Step Uplifting Essential Oils Kit
$24.98$22.48
Add to Cart +
Plan Toys Fire Truck
$14.99
Add to Cart +
Melissa & Doug Mess-Free Glitter Underwater Scenes
$6.98
Add to Cart +
Jarware Tea Infuser
$9.99$7.49
Add to Cart +
aden + anais Shine on Bandana Bib
$9.99

### What's New
View All

Next Prev
Add to Cart +
UPPAbaby MESA Infant Car Seat Denny Red
$429.99
Add to Cart +
Green Beaver Sunflower Liquid Soap Frosty Mint
$18.99$14.24
Add to Cart +
Britax Boulevard Clicktight Car Seat Metro
$449.99
Add to Cart +
Lifefactory Glass Mug with Cafe Cap & Insulating Sleeve Sage
$27.99
Add to Cart +
aden + anais Classic Swaddling Wrap Whiz Kid
$58.99
Add to Cart +
Geratherm Ovu Control Reusable Ovulation Predictor Using Saliva
$99.99
Add to Cart +
Now Virgin Coconut Oil
$15.99
Add to Cart +
Real Health SuperFoods Smoothie Vanilla
$29.49
Add to Cart +
Bumkins Starter Bib Disney Princess
$4.99
Add to Cart +
Eucerin Eczema Relief Body Creme
$17.99
Add to Cart +
Cocoon Apothecary Kahuna Bubble Bath Lemon Grass & Ylang Ylang
$19.99
Add to Cart +
Malechemy by Cocoon Apothecary Beard Oil Collection
$49.99
Add to Cart +
Hugo Frosch Eco Hot Water Bottle Classic Comfort Norwegian
$31.99
Add to Cart +
Eco-Pioneer Concentrated Pure Vinegar Cleaner
$29.99
Add to Cart +
Oxbow Timothy Carrot
$7.99

### Holiday Hot List
View All

Next Prev
Add to Cart +
Ridley's Games Room Chess and Checkers Set
$23.99$20.39
Add to Cart +
Rosy Rings Bay Garland Oval Wax Sachets
$30.98$24.78
Add to Cart +
Melissa & Doug Snacks & Sweets Food Cart
$229.99$195.49
Add to Cart +
Allison's Christmas DIY Cookie Mix Oatmeal Chocolate Chip
$12.98$11.68
Add to Cart +
Now Solutions Ultrasonic Real Bamboo Oil Diffuser
$79.99$63.99
Add to Cart +
S'well Dark Hearted Stainless Steel Water Bottle
$40.00
Add to Cart +
Pacifica Mini Hand Cream Duo
$13.98$12.58
Add to Cart +
Bodum Caffettiera French Press Coffee Maker Black
$25.00
Add to Cart +
The Honest Company Honest Baby Basics Gift Set
$19.99
Add to Cart +
Mr Men and Little Miss Sunshine Mug
$12.98
Add to Cart +
Thymes Frasier Fir Pine Needle Candle
$27.98$20.98
Add to Cart +
Skip Hop Explore & More Musical Instrument Set
$24.99